==> aplus_chat-0.1.7.tar.gz: lib/helper/utilites.dart <==
import 'package:intl/intl.dart';

class Utilities {
  static String convertTimeStampToDate(timeStamp, {formate}) {
    final DateTime selDate =
        DateTime.fromMillisecondsSinceEpoch(timeStamp * 1000, isUtc: true);
    final DateFormat formatter = DateFormat(formate ?? 'dd/MM/yyyy');
    final String formatted = formatter.format(selDate);
    return formatted;
  }

  static String convertTimeStampToTime(timeStamp) {
    final DateTime selDate =
        DateTime.fromMillisecondsSinceEpoch(timeStamp * 1000);
    var getDate = DateFormat.yMd().add_jm().format(selDate);
    var timeSplit = getDate.split(" ");
    return timeSplit[1] + timeSplit[2];
  }
}

class ChatDateFormatter {
  ChatDateFormatter();

  String groupChatDateHeader(value) {
    DateTime tempDate = DateFormat('yyyy-MM-dd').parse(value);
    String date;
    if (tempDate.day == DateTime.now().day) {
      date = 'Today';
    } else if (tempDate.day == DateTime.now().day - 1) {
      date = 'Yesterday';
    } else {
      date = DateFormat('dd MMM yyyy').format(tempDate);
    }
    return date;
  }

  String getVerboseDateTimeRepresentation(DateTime dateTime) {
    DateTime now = DateTime.now();
    DateTime justNow = now.subtract(const Duration(minutes: 1));
    DateTime localDateTime = dateTime.toLocal();

    if (!localDateTime.difference(justNow).isNegative) {
      return 'Just Now';
    }

    String roughTimeString = DateFormat('jm').format(dateTime);

    if (localDateTime.day == now.day &&
        localDateTime.month == now.month &&
        localDateTime.year == now.year) {
      return roughTimeString;
    }

    DateTime yesterday = now.subtract(const Duration(days: 1));

    if (localDateTime.day == yesterday.day &&
        localDateTime.month == now.month &&
        localDateTime.year == now.year) {
      String roughTime = DateFormat('jm').format(dateTime);
      return 'Yesterday $roughTime';
    }

    if (now.difference(localDateTime).inDays < 4) {
      String weekday = DateFormat(
        'EEEE',
      ).format(localDateTime);

      return '$weekday, $roughTimeString';
    }

    return '${DateFormat(
      'yMd',
    ).format(dateTime)}, $roughTimeString';
  }
}

==> aplus_chat-0.2.14.tar.gz: lib/helper/utilites.dart <==
import 'package:intl/intl.dart';

class Utilities {
  static String convertTimeStampToDate(timeStamp, {formate}) {
    final DateTime selDate =
        DateTime.fromMillisecondsSinceEpoch(timeStamp * 1000, isUtc: true);
    final DateFormat formatter = DateFormat(formate ?? 'dd/MM/yyyy');
    final String formatted = formatter.format(selDate);
    return formatted;
  }

  static String convertTimeStampToTime(timeStamp) {
    final DateTime selDate =
        DateTime.fromMillisecondsSinceEpoch(timeStamp * 1000);
    var getDate = DateFormat.yMd().add_jm().format(selDate);
    var timeSplit = getDate.split(" ");
    // return timeSplit[1] + timeSplit[2];
    return timeSplit[1];
  }
}

class ChatDateFormatter {
  ChatDateFormatter();

  String groupChatDateHeader(value) {
    DateTime tempDate = DateFormat('yyyy-MM-dd').parse(value);
    String date;
    if (tempDate.day == DateTime.now().day) {
      date = 'Today';
    } else if (tempDate.day == DateTime.now().day - 1) {
      date = 'Yesterday';
    } else {
      date = DateFormat('dd MMM yyyy').format(tempDate);
    }
    return date;
  }

  String getVerboseDateTimeRepresentation(DateTime dateTime) {
    DateTime now = DateTime.now();
    DateTime justNow = now.subtract(const Duration(minutes: 1));
    DateTime localDateTime = dateTime.toLocal();

    if (!localDateTime.difference(justNow).isNegative) {
      return 'Just Now';
    }

    String roughTimeString = DateFormat('jm').format(dateTime);

    if (localDateTime.day == now.day &&
        localDateTime.month == now.month &&
        localDateTime.year == now.year) {
      return roughTimeString;
    }

    DateTime yesterday = now.subtract(const Duration(days: 1));

    if (localDateTime.day == yesterday.day &&
        localDateTime.month == now.month &&
        localDateTime.year == now.year) {
      String roughTime = DateFormat('jm').format(dateTime);
      return 'Yesterday $roughTime';
    }

    if (now.difference(localDateTime).inDays < 4) {
      String weekday = DateFormat(
        'EEEE',
      ).format(localDateTime);

      return '$weekday, $roughTimeString';
    }

    return '${DateFormat(
      'yMd',
    ).format(dateTime)}, $roughTimeString';
  }
}
